# 🐝 BeePy

## The _frontend_ web framework for python 
## This package loads [beepy-web](https://pypi.org/project/beepy-web/) and provides some JS utils for it

### Thanks for [Pyodide](https://pyodide.org/) - port of Python to [Emscripten](https://emscripten.org/), based on [WASM](https://webassembly.org/).
### Use Python in browser to build modern frontend via BeePy!

## Try it out! [CodeSandBox](https://codesandbox.io/s/beepy-two-synced-counters-k5sm9j) and [BeePy Sandbox](https://kor0p.github.io/BeePy/examples/sandbox/)

## Join our community at [Telegram chat](https://t.me/bee_py/)

# See [documentation](https://bee-py.readthedocs.io/en/latest/) for more info
